@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """Test for tmuxp command line interface."""
-
 from __future__ import absolute_import
 
 import json
@@ -116,13 +115,20 @@ def projectdir(homedir):
 
 
 def test_tmuxp_configdir_env_var(tmpdir, monkeypatch):
-    monkeypatch.setenv('TMUXP_CONFIGDIR', tmpdir)
+    monkeypatch.setenv('TMUXP_CONFIGDIR', str(tmpdir))
 
     assert get_config_dir() == tmpdir
 
 
+def test_tmuxp_configdir_xdg_config_dir(tmpdir, monkeypatch):
+    monkeypatch.setenv('XDG_CONFIG_HOME', str(tmpdir))
+    tmux_dir = tmpdir.mkdir("tmuxp")
+
+    assert get_config_dir() == str(tmux_dir)
+
+
 def test_resolve_dot(tmpdir, homedir, configdir, projectdir, monkeypatch):
-    monkeypatch.setenv('HOME', homedir)
+    monkeypatch.setenv('HOME', str(homedir))
     projectdir.join('.tmuxp.yaml').ensure()
     user_config_name = 'myconfig'
     user_config = configdir.join('%s.yaml' % user_config_name).ensure()
@@ -226,7 +232,7 @@ def test_scan_config_arg(homedir, configdir, projectdir, monkeypatch):
     def config_cmd(config):
         click.echo(config)
 
-    monkeypatch.setenv('HOME', homedir)
+    monkeypatch.setenv('HOME', str(homedir))
     projectdir.join('.tmuxp.yaml').ensure()
     user_config_name = 'myconfig'
     user_config = configdir.join('%s.yaml' % user_config_name).ensure()
@@ -466,6 +472,36 @@ def test_import_tmuxinator(cli_args, inputs, tmpdir, monkeypatch):
         assert tmpdir.join('la.yaml').check()
 
 
+@pytest.mark.parametrize(
+    "cli_args,inputs",
+    [
+        (['freeze', 'mysession'], ['\n', 'y\n', './la.yaml\n', 'y\n']),
+        (  # Exists
+            ['freeze', 'mysession'],
+            ['\n', 'y\n', './exists.yaml\n', './la.yaml\n', 'y\n'],
+        ),
+        (  # Imply current session if not entered
+            ['freeze'],
+            ['\n', 'y\n', './la.yaml\n', 'y\n'],
+        ),
+        (['freeze'], ['\n', 'y\n', './exists.yaml\n', './la.yaml\n', 'y\n']),  # Exists
+    ],
+)
+def test_freeze(server, cli_args, inputs, tmpdir, monkeypatch):
+    monkeypatch.setenv('HOME', str(tmpdir))
+    tmpdir.join('exists.yaml').ensure()
+
+    server.new_session(session_name='mysession')
+
+    with tmpdir.as_cwd():
+        runner = CliRunner()
+        # Use tmux server (socket name) used in the test
+        cli_args = cli_args + ['-L', server.socket_name]
+        out = runner.invoke(cli.cli, cli_args, input=''.join(inputs))
+        print(out.output)
+        assert tmpdir.join('la.yaml').check()
+
+
 def test_get_abs_path(tmpdir):
     expect = str(tmpdir)
     with tmpdir.as_cwd():
