@@ -1,10 +1,12 @@
 __title__ = 'tmuxp'
 __package_name__ = 'tmuxp'
-__version__ = '1.5.0a1'
+__version__ = '1.5.4'
 __description__ = 'tmux session manager'
 __email__ = 'tony@git-pull.com'
 __author__ = 'Tony Narlock'
 __github__ = 'https://github.com/tmux-python/tmuxp'
+__docs__ = 'https://tmuxp.git-pull.com'
+__tracker__ = 'https://github.com/tmux-python/tmuxp/issues'
 __pypi__ = 'https://pypi.org/project/tmuxp/'
 __license__ = 'MIT'
-__copyright__ = 'Copyright 2013-2018 Tony Narlock'
+__copyright__ = 'Copyright 2013- Tony Narlock'
